import * as codebuild from "../../../../aws-codebuild";
import * as codepipeline from "../../../../aws-codepipeline";
import * as ec2 from "../../../../aws-ec2";
import * as events from "../../../../aws-events";
import * as iam from "../../../../aws-iam";
import { IDependable } from "../../../../core";
import { Construct } from 'constructs';
import { AssetType } from '../../blueprint/asset-type';
import { Construct as CoreConstruct } from "../../../../core";
/**
 * (experimental) Props for a PublishAssetsAction.
 *
 * @experimental
 */
export interface PublishAssetsActionProps {
    /**
     * (experimental) Name of publishing action.
     *
     * @experimental
     */
    readonly actionName: string;
    /**
     * (experimental) The CodePipeline artifact that holds the Cloud Assembly.
     *
     * @experimental
     */
    readonly cloudAssemblyInput: codepipeline.Artifact;
    /**
     * (experimental) AssetType we're publishing.
     *
     * @experimental
     */
    readonly assetType: AssetType;
    /**
     * (experimental) Version of CDK CLI to 'npm install'.
     *
     * @default - Latest version
     * @experimental
     */
    readonly cdkCliVersion?: string;
    /**
     * (experimental) Name of the CodeBuild project.
     *
     * @default - Automatically generated
     * @experimental
     */
    readonly projectName?: string;
    /**
     * (experimental) Role to use for CodePipeline and CodeBuild to build and publish the assets.
     *
     * @default - Automatically generated
     * @experimental
     */
    readonly role?: iam.IRole;
    /**
     * (experimental) Any Dependable construct that the CodeBuild project needs to take a dependency on.
     *
     * @default - none
     * @experimental
     */
    readonly dependable?: IDependable;
    /**
     * (experimental) The VPC where to execute the PublishAssetsAction.
     *
     * @default - No VPC
     * @experimental
     */
    readonly vpc?: ec2.IVpc;
    /**
     * (experimental) Which subnets to use.
     *
     * Only used if 'vpc' is supplied.
     *
     * @default - All private subnets.
     * @experimental
     */
    readonly subnetSelection?: ec2.SubnetSelection;
    /**
     * (experimental) Custom BuildSpec that is merged with generated one.
     *
     * @default - none
     * @experimental
     */
    readonly buildSpec?: codebuild.BuildSpec;
    /**
     * (experimental) Use a file buildspec written to the cloud assembly instead of an inline buildspec.
     *
     * This prevents size limitation errors as inline specs have a max length of 25600 characters
     *
     * @default false
     * @experimental
     */
    readonly createBuildspecFile?: boolean;
    /**
     * (experimental) Additional commands to run before installing cdk-assert Use this to setup proxies or npm mirrors.
     *
     * @default -
     * @experimental
     */
    readonly preInstallCommands?: string[];
}
/**
 * (experimental) Action to publish an asset in the pipeline.
 *
 * Creates a CodeBuild project which will use the CDK CLI
 * to prepare and publish the asset.
 *
 * You do not need to instantiate this action -- it will automatically
 * be added by the pipeline when you add stacks that use assets.
 *
 * @experimental
 */
export declare class PublishAssetsAction extends CoreConstruct implements codepipeline.IAction {
    private readonly props;
    private readonly action;
    private readonly commands;
    private readonly buildSpec;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: PublishAssetsActionProps);
    private getBuildSpecFileName;
    private _onSynth;
    /**
     * (experimental) Add a single publishing command.
     *
     * Manifest path should be relative to the root Cloud Assembly.
     *
     * @experimental
     */
    addPublishCommand(relativeManifestPath: string, assetSelector: string): void;
    /**
     * (experimental) Exists to implement IAction.
     *
     * @experimental
     */
    bind(scope: CoreConstruct, stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
    /**
     * (experimental) Exists to implement IAction.
     *
     * @experimental
     */
    onStateChange(name: string, target?: events.IRuleTarget, options?: events.RuleProps): events.Rule;
    /**
     * (experimental) Exists to implement IAction.
     *
     * @experimental
     */
    get actionProperties(): codepipeline.ActionProperties;
}
